@@ -5,10 +5,11 @@ use strict;
 
 use Carp;
 use Try::Tiny;
+use Scalar::Util qw(blessed);
 
 # ABSTRACT: Plugin to check Phone numbers (basic check)
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 
 sub check {
@@ -20,14 +21,21 @@ sub check {
         my $country = $config->{country};
         my $return = 0;
         my $number;
+        my $error;
 
         require 'Number/Phone.pm';
 
         try {
             $number = Number::Phone->new( $country, $value );
+
+            return if !blessed $number;
+
+            $error = 'No support for ' . $country if $number->isa('Number::Phone::StubCountry');
+
+            $return = 1;
         };
 
-        $return = 1 if $number;
+        croak $error if $error;
 
         return $return;
     }
@@ -55,7 +63,7 @@ Data::Validate::WithYAML::Plugin::Phone - Plugin to check Phone numbers (basic c
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
